==> libgwenhywfar_1.18.0.orig.tar.gz: gwenhywfar-1.18.0/src/os/gwentime_l.h <==
/***************************************************************************
 $RCSfile: gwentime_l.h,v $
                             -------------------
    cvs         : $Id: gwentime_l.h,v 1.2 2004/11/19 12:26:31 aquamaniac Exp $
    begin       : Wed Mar 24 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWEN_TIME_L_H
#define GWEN_TIME_L_H


#include <gwenhywfar/gwenhywfarapi.h>
#include <gwenhywfar/types.h>
#include <gwenhywfar/gwentime.h>
#include <gwenhywfar/misc.h>


#ifdef __cplusplus
extern "C" {
#endif

/**
 * This function is called by OS dependant implementations of
 * @ref GWEN_Time__GetCurrentTime.
 */
void GWEN_Time__SetSecsAndMSecs(GWEN_TIME *ti,
                                GWEN_TYPE_UINT32 secs,
                                GWEN_TYPE_UINT32 msecs);

/** @name Functions to be implemented by OS specific modules
 *
 */
/*@{*/
int GWEN_Time__GetCurrentTime(GWEN_TIME *ti);

/*@}*/


#ifdef __cplusplus
}
#endif



#endif

==> libgwenhywfar_3.2.0.orig.tar.gz: gwenhywfar-3.2.0/src/os/gwentime_l.h <==
/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: gwentime_l.h 1393 2007-11-22 18:26:05Z martin $
    begin       : Wed Mar 24 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWEN_TIME_L_H
#define GWEN_TIME_L_H


#include <gwenhywfar/gwenhywfarapi.h>
#include <gwenhywfar/types.h>
#include <gwenhywfar/gwentime.h>
#include <gwenhywfar/misc.h>


#ifdef __cplusplus
extern "C" {
#endif

/**
 * This function is called by OS dependant implementations of
 * @ref GWEN_Time__GetCurrentTime.
 */
void GWEN_Time__SetSecsAndMSecs(GWEN_TIME *ti,
                                uint32_t secs,
                                uint32_t msecs);

/** @name Functions to be implemented by OS specific modules
 *
 */
/*@{*/
int GWEN_Time__GetCurrentTime(GWEN_TIME *ti);

/*@}*/


#ifdef __cplusplus
}
#endif



#endif
